Crate test_fork

Crate test_fork 

A crate providing a replacement #[test] attribute (and others) for running tests in separate processes.

Re-exports

pub use test_fork_core;

Attribute Macros

benchunsound and unstable
A procedural macro for running a benchmark in a separate process.
fork
A procedural macro for running a test or benchmark in a separate process.
test
A procedural macro for running a test in a separate process.